@@ -96,7 +96,7 @@ class AbstractSettingsMaskedInterferometer(
             The type of grid used to create the image from the *Galaxy* and *Plane*. The options are *Grid*,
             *GridIterate* and *GridInterpolate* (see the *Grids* documentation for a description of these options).
         grid_inversion_class : ag.Grid
-            The type of grid used to create the grid that maps the _Inversion_ source pixels to the data's image-pixels.
+            The type of grid used to create the grid that maps the `Inversion` source pixels to the data's image-pixels.
             The options are *Grid*, *GridIterate* and *GridInterpolate* (see the *Grids* documentation for a
             description of these options).
         sub_size : int
@@ -180,7 +180,7 @@ class AbstractMaskedInterferometer(abstract_dataset.AbstractMaskedDataset):
         ----------
         imaging: im.Imaging
             The imaging data_type all in 2D (the image, noise-map, etc.)
-        real_space_mask: msk.Mask
+        real_space_mask: msk.Mask2D
             The 2D mask that is applied to the image.
         """
 
