@@ -205,7 +205,7 @@ class TestMaskedInterferometer:
 
         visibilities_mask = np.full(fill_value=False, shape=(19, 2))
 
-        real_space_mask = aa.Mask.unmasked(
+        real_space_mask = aa.Mask2D.unmasked(
             shape_2d=(19, 19), pixel_scales=1.0, invert=True, sub_size=8
         )
         real_space_mask[9, 9] = False
@@ -270,7 +270,7 @@ class TestSimulatorInterferometer:
 
         transformer = simulator.transformer_class(
             uv_wavelengths=uv_wavelengths_7x2,
-            real_space_mask=aa.Mask.unmasked(
+            real_space_mask=aa.Mask2D.unmasked(
                 shape_2d=(3, 3), pixel_scales=image.pixel_scales
             ),
         )
@@ -312,7 +312,7 @@ class TestSimulatorInterferometer:
 
         transformer = simulator.transformer_class(
             uv_wavelengths=uv_wavelengths_7x2,
-            real_space_mask=aa.Mask.unmasked(
+            real_space_mask=aa.Mask2D.unmasked(
                 shape_2d=(3, 3), pixel_scales=image.pixel_scales
             ),
         )
@@ -348,7 +348,7 @@ class TestSimulatorInterferometer:
 
         transformer = simulator.transformer_class(
             uv_wavelengths=uv_wavelengths_7x2,
-            real_space_mask=aa.Mask.unmasked(
+            real_space_mask=aa.Mask2D.unmasked(
                 shape_2d=(3, 3), pixel_scales=image.pixel_scales
             ),
         )
