@@ -8,7 +8,7 @@ from test_autoarray import mock
 class TestFitImaging:
     def test__image_and_model_are_identical__no_masking__check_values_are_correct(self):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
@@ -67,7 +67,7 @@ class TestFitImaging:
         self
     ):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array([[False, False], [True, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
@@ -120,7 +120,7 @@ class TestFitImaging:
         self
     ):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
@@ -170,7 +170,7 @@ class TestFitInterferometer:
 
         visibilities_mask = np.full(fill_value=False, shape=(2, 2))
 
-        real_space_mask = aa.Mask.manual(
+        real_space_mask = aa.Mask2D.manual(
             mask=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
@@ -235,7 +235,7 @@ class TestFitInterferometer:
 
         visibilities_mask = np.full(fill_value=False, shape=(2, 2))
 
-        real_space_mask = aa.Mask.manual(
+        real_space_mask = aa.Mask2D.manual(
             mask=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
@@ -300,7 +300,7 @@ class TestFitInterferometer:
 
         visibilities_mask = np.full(fill_value=False, shape=(2, 2))
 
-        real_space_mask = aa.Mask.manual(
+        real_space_mask = aa.Mask2D.manual(
             mask=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
