@@ -20,7 +20,7 @@ class TestRectangular:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=1.0, sub_size=1)
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=1.0, sub_size=1)
 
         # Source-plane comprises 5 grid, so 5 masked_image pixels traced to the pix-plane.
 
@@ -115,7 +115,7 @@ class TestRectangular:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=1.0, sub_size=1)
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=1.0, sub_size=1)
 
         # There is no sub-grid, so our grid are just the masked_image grid (note the NumPy weighted_data structure
         # ensures this has no sub-gridding)
@@ -235,7 +235,7 @@ class TestRectangular:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=2.0, sub_size=2)
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=2.0, sub_size=2)
 
         # Assume a 2x2 sub-grid, so each of our 5 masked_image-pixels are split into 4.
         # The grid below is unphysical in that the (0.0, 0.0) terms on the end of each sub-grid probably couldn't
@@ -350,7 +350,7 @@ class TestRectangular:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=1.0, sub_size=1)
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=1.0, sub_size=1)
 
         grid = aa.Grid.manual_mask(
             grid=np.array(
@@ -442,7 +442,7 @@ class TestRectangular:
             ]
         )
 
-        real_space_mask = aa.Mask.manual(
+        real_space_mask = aa.Mask2D.manual(
             mask=real_space_mask, pixel_scales=0.1, sub_size=1
         )
 
@@ -514,7 +514,7 @@ class TestRectangular:
             ]
         )
 
-        real_space_mask = aa.Mask.manual(
+        real_space_mask = aa.Mask2D.manual(
             mask=real_space_mask, pixel_scales=0.1, sub_size=1
         )
 
@@ -579,7 +579,7 @@ class TestRectangular:
 class TestVoronoiMagnification:
     def test__3x3_simple_grid(self):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [
                     [True, True, True, True, True],
@@ -694,7 +694,7 @@ class TestVoronoiMagnification:
 
     def test__3x3_simple_grid__include_mask(self):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [
                     [True, True, True, True, True],
@@ -787,7 +787,7 @@ class TestVoronoiMagnification:
 
     def test__3x3_simple_grid__include_mask_and_sub_grid(self):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [
                     [True, True, True, True, True],
@@ -901,7 +901,7 @@ class TestVoronoiMagnification:
 
     def test__3x3_simple_grid__include_mask_with_offset_centre(self):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [
                     [True, True, True, True, True, True, True],
@@ -1010,7 +1010,7 @@ class TestVoronoiMagnification:
             ]
         )
 
-        real_space_mask = aa.Mask.manual(
+        real_space_mask = aa.Mask2D.manual(
             mask=real_space_mask, pixel_scales=0.1, sub_size=1
         )
 
