@@ -7,34 +7,34 @@ import autoarray as aa
 class TestCoordinates:
     def test__central_pixel__depends_on_shape_pixel_scale_and_origin(self):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(0.1, 0.1)
         )
         assert mask.geometry.central_pixel_coordinates == (1, 1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(4, 4)), pixel_scales=(0.1, 0.1)
         )
         assert mask.geometry.central_pixel_coordinates == (1.5, 1.5)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(5, 3)),
             pixel_scales=(0.1, 0.1),
             origin=(1.0, 2.0),
         )
         assert mask.geometry.central_pixel_coordinates == (2.0, 1.0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(2.0, 1.0)
         )
         assert mask.geometry.central_pixel_coordinates == (1, 1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(4, 4)), pixel_scales=(2.0, 1.0)
         )
         assert mask.geometry.central_pixel_coordinates == (1.5, 1.5)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(5, 3)),
             pixel_scales=(2.0, 1.0),
             origin=(1.0, 2.0),
@@ -50,7 +50,7 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (0.0, 0.0)
 
@@ -62,7 +62,7 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (0.0, 0.5)
 
@@ -74,7 +74,7 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (0.5, 0.0)
 
@@ -86,7 +86,7 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (0.0, -0.5)
 
@@ -98,7 +98,7 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (-0.5, 0.0)
 
@@ -110,117 +110,117 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (-0.5, -0.5)
 
     def test__pixel_grid__y_and_x_ticks(self):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(0.5, 0.5)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-0.75, -0.25, 0.25, 0.75]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(6, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-3.0, -1.0, 1.0, 3.0]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 1)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(0.5, 0.5)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-0.75, -0.25, 0.25, 0.75]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 6)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-3.0, -1.0, 1.0, 3.0]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(1, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 5.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(0.5, 5.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-0.75, -0.25, 0.25, 0.75]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(6, 3)), pixel_scales=(1.0, 5.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-3.0, -1.0, 1.0, 3.0]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 6)), pixel_scales=(1.0, 5.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(5.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(5.0, 0.5)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-0.75, -0.25, 0.25, 0.75]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 6)), pixel_scales=(5.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-3.0, -1.0, 1.0, 3.0]), 1e-3
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(6, 3)), pixel_scales=(5.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
@@ -239,7 +239,7 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.56, 0.56), sub_size=1
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(4, 7)), pixel_scales=(0.56, 0.56)
         )
         mask[0, 0] = True
@@ -255,7 +255,7 @@ class TestGrids:
             == np.full(fill_value=False, shape=(4, 7))
         ).all()
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
 
@@ -278,7 +278,7 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.8, 0.56), sub_size=1
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(4, 7)), pixel_scales=(0.8, 0.56)
         )
 
@@ -289,7 +289,7 @@ class TestGrids:
             grid_2d_util, 1e-4
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 2.0)
         )
 
@@ -310,7 +310,7 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.56, 0.56), origin=(1.0, 3.0), sub_size=1
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(4, 7)),
             pixel_scales=(0.56, 0.56),
             origin=(1.0, 3.0),
@@ -324,7 +324,7 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.56, 0.56), origin=(-1.0, -4.0), sub_size=1
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(4, 7)),
             pixel_scales=(0.56, 0.56),
             origin=(-1.0, -4.0),
@@ -338,7 +338,7 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.8, 0.56), origin=(1.0, 2.0), sub_size=1
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(4, 7)),
             pixel_scales=(0.8, 0.56),
             origin=(1.0, 2.0),
@@ -352,7 +352,7 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.8, 0.56), origin=(-1.0, -4.0), sub_size=1
         )
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(4, 7)),
             pixel_scales=(0.8, 0.56),
             origin=(-1.0, -4.0),
@@ -364,7 +364,7 @@ class TestGrids:
 
     def test__masked_grids_1d(self):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
 
@@ -385,7 +385,7 @@ class TestGrids:
             )
         ).all()
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
         mask[1, 1] = True
@@ -406,7 +406,7 @@ class TestGrids:
             )
         ).all()
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array([[False, True], [True, False], [True, False]]),
             pixel_scales=(1.0, 1.0),
             origin=(3.0, -2.0),
@@ -432,7 +432,7 @@ class TestGrids:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.edge_grid_sub_1.in_1d[0:11] == pytest.approx(
             np.array(
@@ -468,7 +468,7 @@ class TestGrids:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.border_grid_sub_1.in_1d[0:11] == pytest.approx(
             np.array(
@@ -490,7 +490,7 @@ class TestGrids:
         )
 
     def test__masked_sub_grid(self):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)),
             pixel_scales=(1.0, 1.0),
             sub_size=1,
@@ -513,7 +513,7 @@ class TestGrids:
             )
         ).all()
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)),
             pixel_scales=(1.0, 1.0),
             sub_size=2,
@@ -543,7 +543,7 @@ class TestGrids:
             )
         ).all()
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)),
             pixel_scales=(1.0, 1.0),
             sub_size=1,
@@ -566,7 +566,7 @@ class TestGrids:
             )
         ).all()
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array([[False, True], [True, False], [True, False]]),
             pixel_scales=(1.0, 1.0),
             sub_size=5,
@@ -593,7 +593,7 @@ class TestGrids:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0), sub_size=2)
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=(1.0, 1.0), sub_size=2)
 
         assert (
             mask.geometry.border_grid_1d
@@ -612,7 +612,7 @@ class TestGrids:
             ]
         )
 
-        mask = aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0), sub_size=2)
+        mask = aa.Mask2D.manual(mask=mask, pixel_scales=(1.0, 1.0), sub_size=2)
 
         assert (
             mask.geometry.border_grid_1d
@@ -634,7 +634,7 @@ class TestGrids:
 class TestArcsecToPixel:
     def test__pixel_coordinates_from_arcsec_coordinates(self):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -651,7 +651,7 @@ class TestArcsecToPixel:
             scaled_coordinates=(-1.0, 1.0)
         ) == (1, 1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(3.0, 3.0)
         )
 
@@ -685,7 +685,7 @@ class TestArcsecToPixel:
 
     def test__pixel_coordinates_from_arcsec_coordinates__arcsec_are_pixel_corners(self):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -744,7 +744,7 @@ class TestArcsecToPixel:
     def test__pixel_coordinates_from_arcsec_coordinates___arcsec_are_pixel_centres__nonzero_centre(
         self
     ):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)),
             pixel_scales=(2.0, 2.0),
             origin=(1.0, 1.0),
@@ -763,7 +763,7 @@ class TestArcsecToPixel:
             scaled_coordinates=(0.0, 2.0)
         ) == (1, 1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)),
             pixel_scales=(3.0, 3.0),
             origin=(3.0, 3.0),
@@ -800,7 +800,7 @@ class TestArcsecToPixel:
     def test__pixel_coordinates_from_arcsec_coordinates__arcsec_are_pixel_corners__nonzero_centre(
         self
     ):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)),
             pixel_scales=(2.0, 2.0),
             origin=(1.0, 1.0),
@@ -861,7 +861,7 @@ class TestArcsecToPixel:
     def test__scaled_coordinates_from_pixel_coordinates___scaled_are_pixel_centres__nonzero_centre(
         self
     ):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(3.0, 3.0)
         )
 
@@ -893,7 +893,7 @@ class TestArcsecToPixel:
             pixel_coordinates=(2, 2)
         ) == (-3.0, 3.0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)),
             pixel_scales=(2.0, 2.0),
             origin=(1.0, 1.0),
@@ -912,7 +912,7 @@ class TestArcsecToPixel:
             pixel_coordinates=(1, 1)
         ) == (0.0, 2.0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)),
             pixel_scales=(3.0, 3.0),
             origin=(3.0, 3.0),
@@ -949,7 +949,7 @@ class TestArcsecToPixel:
 
 class TestGridConversions:
     def test__grid_pixels_from_grid_arcsec(self):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 4.0)
         )
 
@@ -967,7 +967,7 @@ class TestGridConversions:
 
     def test__grid_pixel_centres_1d_from_grid_arcsec_1d__same_as_grid_util(self):
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -983,7 +983,7 @@ class TestGridConversions:
 
         assert (grid_pixels == grid_pixels_util).all()
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(7.0, 2.0)
         )
 
@@ -1000,7 +1000,7 @@ class TestGridConversions:
         assert (grid_pixels == grid_pixels_util).all()
 
     def test__grid_pixel_indexes_1d_from_grid_arcsec_1d__same_as_grid_util(self):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -1016,7 +1016,7 @@ class TestGridConversions:
 
         assert (grid_pixel_indexes == grid_pixel_indexes_util).all()
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 4.0)
         )
 
@@ -1033,7 +1033,7 @@ class TestGridConversions:
         assert (grid_pixels == grid_pixels_util).all()
 
     def test__grid_arcsec_1d_from_grid_pixels_1d__same_as_grid_util(self):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -1049,7 +1049,7 @@ class TestGridConversions:
 
         assert (grid_pixels == grid_pixels_util).all()
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -1065,7 +1065,7 @@ class TestGridConversions:
         assert (grid_pixels == grid_pixels_util).all()
 
     def test__pixel_grid__grids_with_nonzero_centres__same_as_grid_util(self):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)),
             pixel_scales=(2.0, 2.0),
             origin=(1.0, 2.0),
@@ -1123,7 +1123,7 @@ class TestGridConversions:
 
         grid_arcsec = np.array([[1.0, -2.0], [1.0, 2.0], [-1.0, -2.0], [-1.0, 2.0]])
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(2, 2)),
             pixel_scales=(2.0, 1.0),
             origin=(1.0, 2.0),
@@ -1180,57 +1180,57 @@ class TestGridConversions:
 
 class TestZoomCentreAndOffet:
     def test__odd_sized_false_mask__centre_is_0_0__pixels_from_centre_are_0_0(self):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (1.0, 1.0)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(5, 5)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (2.0, 2.0)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(3, 5)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (1.0, 2.0)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(5, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (2.0, 1.0)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
     def test__even_sized_false_mask__centre_is_0_0__pixels_from_centre_are_0_0(self):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(4, 4)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (1.5, 1.5)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(6, 6)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (2.5, 2.5)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(4, 6)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (1.5, 2.5)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.full(fill_value=False, shape=(6, 4)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (2.5, 1.5)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
     def test__mask_is_single_false__extraction_centre_is_central_pixel(self):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[False, True, True], [True, True, True], [True, True, True]]
             ),
@@ -1239,7 +1239,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (0, 0)
         assert mask.geometry._zoom_offset_pixels == (-1, -1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[True, True, False], [True, True, True], [True, True, True]]
             ),
@@ -1248,7 +1248,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (0, 2)
         assert mask.geometry._zoom_offset_pixels == (-1, 1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[True, True, True], [True, True, True], [False, True, True]]
             ),
@@ -1257,7 +1257,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (2, 0)
         assert mask.geometry._zoom_offset_pixels == (1, -1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[True, True, True], [True, True, True], [True, True, False]]
             ),
@@ -1266,7 +1266,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (2, 2)
         assert mask.geometry._zoom_offset_pixels == (1, 1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[True, False, True], [True, True, True], [True, True, True]]
             ),
@@ -1275,7 +1275,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (0, 1)
         assert mask.geometry._zoom_offset_pixels == (-1, 0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[True, True, True], [False, True, True], [True, True, True]]
             ),
@@ -1284,7 +1284,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (1, 0)
         assert mask.geometry._zoom_offset_pixels == (0, -1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[True, True, True], [True, True, False], [True, True, True]]
             ),
@@ -1293,7 +1293,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (1, 2)
         assert mask.geometry._zoom_offset_pixels == (0, 1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[True, True, True], [True, True, True], [True, False, True]]
             ),
@@ -1303,7 +1303,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_offset_pixels == (1, 0)
 
     def test__mask_is_x2_false__extraction_centre_is_central_pixel(self):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[False, True, True], [True, True, True], [True, True, False]]
             ),
@@ -1312,7 +1312,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (1, 1)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[False, True, True], [True, True, True], [False, True, True]]
             ),
@@ -1321,7 +1321,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (1, 0)
         assert mask.geometry._zoom_offset_pixels == (0, -1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[False, True, False], [True, True, True], [True, True, True]]
             ),
@@ -1330,7 +1330,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (0, 1)
         assert mask.geometry._zoom_offset_pixels == (-1, 0)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [[False, False, True], [True, True, True], [True, True, True]]
             ),
@@ -1340,7 +1340,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_offset_pixels == (-1, -0.5)
 
     def test__rectangular_mask(self):
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [
                     [False, True, True, True],
@@ -1354,7 +1354,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (0, 0)
         assert mask.geometry._zoom_offset_pixels == (-1.0, -1.5)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [
                     [True, True, True, True],
@@ -1368,7 +1368,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (2, 3)
         assert mask.geometry._zoom_offset_pixels == (1.0, 1.5)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [
                     [True, True, True, True, True],
@@ -1382,7 +1382,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (2, 4)
         assert mask.geometry._zoom_offset_pixels == (1, 2)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [
                     [True, True, True, True, True, True, True],
@@ -1396,7 +1396,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (2, 6)
         assert mask.geometry._zoom_offset_pixels == (1, 3)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [
                     [True, True, True],
@@ -1412,7 +1412,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (4, 2)
         assert mask.geometry._zoom_offset_pixels == (2, 1)
 
-        mask = aa.Mask.manual(
+        mask = aa.Mask2D.manual(
             mask=np.array(
                 [
                     [True, True, True],
